<?php

namespace Litecms\Rouletegame\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Rouletegame\Interfaces\RouletegameRepositoryInterface;

class RouletegamePublicController extends BaseController
{
    // use RouletegameWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Rouletegame\Interfaces\RouletegameRepositoryInterface $rouletegame
     *
     * @return type
     */
    public function __construct(RouletegameRepositoryInterface $rouletegame)
    {
        $this->repository = $rouletegame;
        parent::__construct();
    }

    /**
     * Show rouletegame's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $rouletegames = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$rouletegame::$rouletegame.names'))
            ->view('$rouletegame::public.rouletegame.index')
            ->data(compact('$rouletegames'))
            ->output();
    }

    /**
     * Show rouletegame's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $rouletegames = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$rouletegame::$rouletegame.names'))
            ->view('$rouletegame::public.rouletegame.index')
            ->data(compact('$rouletegames'))
            ->output();
    }

    /**
     * Show rouletegame.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $rouletegame = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$rouletegame->name . trans('$rouletegame::$rouletegame.name'))
            ->view('$rouletegame::public.rouletegame.show')
            ->data(compact('$rouletegame'))
            ->output();
    }

}
