<?php

namespace Litecms\Rouletegame\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Rouletegame\Http\Requests\RouletegameRequest;
use Litecms\Rouletegame\Interfaces\RouletegameRepositoryInterface;
use Litecms\Rouletegame\Models\Rouletegame;

/**
 * Resource controller class for rouletegame.
 */
class RouletegameResourceController extends BaseController
{

    /**
     * Initialize rouletegame resource controller.
     *
     * @param type RouletegameRepositoryInterface $rouletegame
     *
     * @return null
     */
    public function __construct(RouletegameRepositoryInterface $rouletegame)
    {
        parent::__construct();
        $this->repository = $rouletegame;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Rouletegame\Repositories\Criteria\RouletegameResourceCriteria::class);
    }

    /**
     * Display a list of rouletegame.
     *
     * @return Response
     */
    public function index(RouletegameRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Rouletegame\Repositories\Presenter\RouletegamePresenter::class)
                ->$function();
        }

        $rouletegames = $this->repository->paginate();

        return $this->response->title(trans('rouletegame::rouletegame.names'))
            ->view('rouletegame::rouletegame.index', true)
            ->data(compact('rouletegames'))
            ->output();
    }

    /**
     * Display rouletegame.
     *
     * @param Request $request
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function show(RouletegameRequest $request, Rouletegame $rouletegame)
    {

        if ($rouletegame->exists) {
            $view = 'rouletegame::rouletegame.show';
        } else {
            $view = 'rouletegame::rouletegame.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('rouletegame::rouletegame.name'))
            ->data(compact('rouletegame'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new rouletegame.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(RouletegameRequest $request)
    {

        $rouletegame = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('rouletegame::rouletegame.name')) 
            ->view('rouletegame::rouletegame.create', true) 
            ->data(compact('rouletegame'))
            ->output();
    }

    /**
     * Create new rouletegame.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(RouletegameRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $rouletegame                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('rouletegame::rouletegame.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('rouletegame/rouletegame/' . $rouletegame->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/rouletegame/rouletegame'))
                ->redirect();
        }

    }

    /**
     * Show rouletegame for editing.
     *
     * @param Request $request
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function edit(RouletegameRequest $request, Rouletegame $rouletegame)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('rouletegame::rouletegame.name'))
            ->view('rouletegame::rouletegame.edit', true)
            ->data(compact('rouletegame'))
            ->output();
    }

    /**
     * Update the rouletegame.
     *
     * @param Request $request
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function update(RouletegameRequest $request, Rouletegame $rouletegame)
    {
        try {
            $attributes = $request->all();

            $rouletegame->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('rouletegame::rouletegame.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('rouletegame/rouletegame/' . $rouletegame->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('rouletegame/rouletegame/' . $rouletegame->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the rouletegame.
     *
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function destroy(RouletegameRequest $request, Rouletegame $rouletegame)
    {
        try {

            $rouletegame->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('rouletegame::rouletegame.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('rouletegame/rouletegame/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('rouletegame/rouletegame/' . $rouletegame->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple rouletegame.
     *
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function delete(RouletegameRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('rouletegame::rouletegame.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('rouletegame/rouletegame'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/rouletegame/rouletegame'))
                ->redirect();
        }

    }

    /**
     * Restore deleted rouletegames.
     *
     * @param Model   $rouletegame
     *
     * @return Response
     */
    public function restore(RouletegameRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('rouletegame::rouletegame.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/rouletegame/rouletegame'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/rouletegame/rouletegame/'))
                ->redirect();
        }

    }

}
