<?php

namespace Litecms\Rouletegame\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Rouletegame\Models\Rouletegame;

class RouletegamePolicy
{

    /**
     * Determine if the given user can view the rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function view(UserPolicy $user, Rouletegame $rouletegame)
    {
        if ($user->canDo('rouletegame.rouletegame.view') && $user->isAdmin()) {
            return true;
        }

        return $rouletegame->user_id == user_id() && $rouletegame->user_type == user_type();
    }

    /**
     * Determine if the given user can create a rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('rouletegame.rouletegame.create');
    }

    /**
     * Determine if the given user can update the given rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function update(UserPolicy $user, Rouletegame $rouletegame)
    {
        if ($user->canDo('rouletegame.rouletegame.edit') && $user->isAdmin()) {
            return true;
        }

        return $rouletegame->user_id == user_id() && $rouletegame->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Rouletegame $rouletegame)
    {
        return $rouletegame->user_id == user_id() && $rouletegame->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Rouletegame $rouletegame)
    {
        if ($user->canDo('rouletegame.rouletegame.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given rouletegame.
     *
     * @param UserPolicy $user
     * @param Rouletegame $rouletegame
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Rouletegame $rouletegame)
    {
        if ($user->canDo('rouletegame.rouletegame.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
