<?php

namespace Litecms\Rouletegame\Providers;

use Illuminate\Support\ServiceProvider;

class RouletegameServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'rouletegame');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'rouletegame');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.rouletegame', function ($app) {
            return $this->app->make('Litecms\Rouletegame\Rouletegame');
        });

                // Bind Rouletegame to repository
        $this->app->bind(
            'Litecms\Rouletegame\Interfaces\RouletegameRepositoryInterface',
            \Litecms\Rouletegame\Repositories\Eloquent\RouletegameRepository::class
        );

        $this->app->register(\Litecms\Rouletegame\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Rouletegame\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.rouletegame'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/rouletegame.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/rouletegame')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/rouletegame')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
